@@ -199,6 +199,9 @@ class Stack:
             return None
         return self.stack[len(self.stack) - index]
 
+    def clear(self):
+        self.stack= []
+
     def pop(self):
         if len(self.stack) < 1:
             return None
